@@ -2,8 +2,11 @@ import json
 import time
 from typing import List
 
-from instagrapi.exceptions import (ClientLoginRequired, ClientNotFoundError,
-                                   LocationNotFound)
+from instagrapi.exceptions import (
+    ClientLoginRequired,
+    ClientNotFoundError,
+    LocationNotFound,
+)
 from instagrapi.extractors import extract_location
 from instagrapi.types import Location, Media
 
